<?php

namespace Yoprueba\Yoprueba\Http\Controllers;

use App\Http\Controllers\UserController as UserController;
use Former;
use Yoprueba\Yoprueba\Http\Requests\CarUserRequest;
use Yoprueba\Yoprueba\Interfaces\CarRepositoryInterface;
use Response;
use User;

class CarUserController extends UserController
{
    /**
     * Initialize car controller.
     *
     * @param type CarRepositoryInterface $car
     *
     * @return type
     */
    public function __construct(CarRepositoryInterface $car)
    {
        $this->model = $car;
        $this->model->setUserFilter();
        parent::__construct();
    }

    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index(CarUserRequest $request)
    {
        $cars = $this->model->all();

        $this->theme->prependTitle(trans('yoprueba::car.names').' :: ');

        return $this->theme->of('yoprueba::user.car.index', compact('cars'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function show(CarUserRequest $request, $role, $id)
    {
        $car = $this->model->find($id);

        return $this->theme->of('yoprueba::user.car.show', compact('car'))->render();
    }

    /**
     * Show the form for creating a new resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(CarUserRequest $request)
    {
        $car = $this->model->findOrNew(0);

        Former::populate($car);

        return $this->theme->of('yoprueba::user.car.create', compact('car'))->render();
    }

    /**
     * Display the specified resource.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(CarUserRequest $request)
    {
        try {
            $attributes = $request->all();
            $car = $this->model->create($attributes);

            return $this->success(trans('messages.success.created', ['Module' => trans('yoprueba::car.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Show the form for editing the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function edit(CarUserRequest $request, $role, $id)
    {
        $car = $this->model->find($id);

        Former::populate($car);

        return $this->theme->of('yoprueba::user.car.edit', compact('car'))->render();
    }

    /**
     * Update the specified resource.
     *
     * @param Request $request
     * @param int     $id
     *
     * @return Response
     */
    public function update(CarUserRequest $request, $role, $id)
    {
        try {
            $attributes = $request->all();
            $car = $this->model->update($attributes, $id);

            return $this->success(trans('messages.success.updated', ['Module' => trans('yoprueba::car.name')]));
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }

    /**
     * Remove the specified resource.
     *
     * @param int $id
     *
     * @return Response
     */
    public function destroy(CarUserRequest $request, $role, $id)
    {
        try {
            $this->model->delete($id);

            return $this->success(trans('message.success.deleted', ['Module' => trans('yoprueba::car.name')]), 200);
        } catch (Exception $e) {
            return $this->error($e->getMessage());
        }
    }
}
